==> react-atom-switch-1.15.0.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import { useState, forwardRef } from 'react';
import PropTypes from 'prop-types';
import { ToggleSwitchTypeRender } from './SwitchType/toggle';
import { SingleSwitchTypeRender } from './SwitchType/single';
import { SIZES, TYPES, SUPPORTED_KEYS } from './config';
import { jsx as _jsx } from "react/jsx-runtime";
var AtomSwitch = /*#__PURE__*/forwardRef(function (props, ref) {
  var initialValue = props.initialValue,
      disabled = props.disabled,
      onToggleCallback = props.onToggle,
      type = props.type;

  var _useState = useState(initialValue),
      isToggle = _useState[0],
      setIsToggle = _useState[1];

  var _useState2 = useState(false),
      isFocus = _useState2[0],
      setIsFocus = _useState2[1];

  var _useState3 = useState(false),
      isClick = _useState3[0],
      setIsClick = _useState3[1];

  var onBlur = function onBlur(ev) {
    var onBlur = props.onBlur;
    setIsFocus(false);
    setIsClick(false);
    typeof onBlur === 'function' && onBlur(ev);
  };

  var onFocus = function onFocus(ev) {
    var onFocus = props.onFocus;
    setTimeout(function () {
      setIsFocus(true);
      typeof onFocus === 'function' && onFocus(ev);
    }, 150);
  };

  var onClick = function onClick() {
    setIsClick(true);
  };

  var onToggle = function onToggle(forceValue) {
    if (disabled === true) return;
    var newIsToggle = forceValue !== undefined ? forceValue : !isToggle;
    setIsToggle(newIsToggle);
    typeof onToggleCallback === 'function' && onToggleCallback(newIsToggle);
  };

  var onKeyDown = function onKeyDown(ev) {
    if (disabled === true) return;

    if (SUPPORTED_KEYS.includes(ev.key)) {
      if (props.value === undefined) {
        // if its uncontrolled component
        onToggle();
      }

      if (typeof onToggleCallback === 'function') {
        onToggleCallback();
      }

      ev.preventDefault();
    }
  };

  var commonProps = _extends({}, props, {
    isFocus: isFocus,
    isClick: isClick,
    isToggle: isToggle,
    onBlur: onBlur,
    onClick: onClick,
    onFocus: onFocus,
    onKeyDown: onKeyDown,
    onToggle: onToggle
  });

  return type === TYPES.SINGLE ? /*#__PURE__*/_jsx(SingleSwitchTypeRender, _extends({
    ref: ref
  }, commonProps)) : /*#__PURE__*/_jsx(ToggleSwitchTypeRender, _extends({
    ref: ref
  }, commonProps));
});
AtomSwitch.displayName = 'AtomSwitch';
AtomSwitch.defaultProps = {
  disabled: false,
  initialValue: false,
  labelLeft: 'Off',
  labelRight: 'On',
  size: SIZES.DEFAULT,
  type: TYPES.TOGGLE
};
export { SIZES as atomSwitchSizes };
export { TYPES as atomSwitchTypes };
export default AtomSwitch;

==> react-atom-switch-1.16.0.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import { useState, forwardRef } from 'react';
import PropTypes from 'prop-types';
import { ToggleSwitchTypeRender } from './SwitchType/toggle';
import { SingleSwitchTypeRender } from './SwitchType/single';
import { LABELS, SIZES, SUPPORTED_KEYS, TYPES } from './config';
import { jsx as _jsx } from "react/jsx-runtime";
var AtomSwitch = /*#__PURE__*/forwardRef(function (props, ref) {
  var initialValue = props.initialValue,
      disabled = props.disabled,
      onToggleCallback = props.onToggle,
      type = props.type;

  var _useState = useState(initialValue),
      isToggle = _useState[0],
      setIsToggle = _useState[1];

  var _useState2 = useState(false),
      isFocus = _useState2[0],
      setIsFocus = _useState2[1];

  var _useState3 = useState(false),
      isClick = _useState3[0],
      setIsClick = _useState3[1];

  var onBlur = function onBlur(ev) {
    var onBlur = props.onBlur;
    setIsFocus(false);
    setIsClick(false);
    typeof onBlur === 'function' && onBlur(ev);
  };

  var onFocus = function onFocus(ev) {
    var onFocus = props.onFocus;
    setTimeout(function () {
      setIsFocus(true);
      typeof onFocus === 'function' && onFocus(ev);
    }, 150);
  };

  var onClick = function onClick() {
    setIsClick(true);
  };

  var onToggle = function onToggle(forceValue) {
    if (disabled === true) return;
    var newIsToggle = forceValue !== undefined ? forceValue : !isToggle;
    setIsToggle(newIsToggle);
    typeof onToggleCallback === 'function' && onToggleCallback(newIsToggle);
  };

  var onKeyDown = function onKeyDown(ev) {
    if (disabled === true) return;

    if (SUPPORTED_KEYS.includes(ev.key)) {
      if (props.value === undefined) {
        // if its uncontrolled component
        onToggle();
      }

      if (typeof onToggleCallback === 'function') {
        onToggleCallback();
      }

      ev.preventDefault();
    }
  };

  var commonProps = _extends({}, props, {
    isFocus: isFocus,
    isClick: isClick,
    isToggle: isToggle,
    onBlur: onBlur,
    onClick: onClick,
    onFocus: onFocus,
    onKeyDown: onKeyDown,
    onToggle: onToggle
  });

  return type === TYPES.SINGLE ? /*#__PURE__*/_jsx(SingleSwitchTypeRender, _extends({
    ref: ref
  }, commonProps)) : /*#__PURE__*/_jsx(ToggleSwitchTypeRender, _extends({
    ref: ref
  }, commonProps));
});
AtomSwitch.displayName = 'AtomSwitch';
AtomSwitch.defaultProps = {
  disabled: false,
  initialValue: false,
  labelLeft: LABELS.LEFT,
  labelRight: LABELS.RIGHT,
  size: SIZES.DEFAULT,
  type: TYPES.TOGGLE
};
export { SIZES as atomSwitchSizes };
export { TYPES as atomSwitchTypes };
export default AtomSwitch;
